# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Capture-Tiny
Version:	0.50
Release:	1.%{__distinit}%{__distvers}
Summary:	Capture STDOUT and STDERR from Perl, XS or external programs
License:	Apache-2.0
URL:		https://metacpan.org/release/Capture-Tiny
Source0:	https://cpan.metacpan.org/authors/id/D/DA/DAGOLDEN/Capture-Tiny-%{version}.tar.gz
Patch1:		Capture-Tiny-0.50-pod-spell.patch
BuildArch:	noarch
# =========== Module Build ==============
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
# =========== Module Runtime ============
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(warnings)
# =========== Test Suite ================
BuildRequires:	perl(Config)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More) >= 0.88
# =========== Optional Tests ============
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# =========== Extra Tests ===============
%if 0%{!?perl_bootstrap:1}
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	perl(blib)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
BuildRequires:	perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling) >= 0.17, hunspell-en
BuildRequires:	perl(Test::Version) >= 1.002
%endif
# =========== Module Dependencies =======
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Time::HiRes)

%description
Capture::Tiny provides a simple, portable way to capture anything sent to
STDOUT or STDERR, regardless of whether it comes from Perl, from XS code or
from an external program. Optionally, output can be teed so that it is
captured while being passed through to the original handles. Yes, it even
works on Windows. Stop guessing which of a dozen capturing modules to use
in any particular situation and just use this one.

%prep
%setup -q -n Capture-Tiny-%{version}

# Additional stopwords for pod spelling test
%patch -P 1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
LANG=en_US.utf8 make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%files
%license LICENSE
%doc Changes CONTRIBUTING.mkdn examples/ README Todo
%{perl_vendorlib}/Capture/
%{_mandir}/man3/Capture::Tiny.3*

%changelog
* Fri Dec 20 2024 Paul Howarth <paul@city-fan.org> - 0.50-1
- Update to 0.50
  - Stringify '$]' for far future compatibility
  - Fixed docs about custom files for capture

* Sat Jul 15 2023 Paul Howarth <paul@city-fan.org> - 0.48-16
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax
- Use %%license unconditionally

* Fri Mar  8 2019 Paul Howarth <paul@city-fan.org> - 0.48-4
- Switch upstream from search.cpan.org to metacpan.org
- Work around mock locale issues by adding buildreq glibc-langpack-en when
  running extra tests

* Mon Apr 23 2018 Paul Howarth <paul@city-fan.org> - 0.48-1
- Update to 0.48
  - Appends PID to random file names for tee signalling to avoid random name
    collision when used in multiple forked children
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Sun Feb 26 2017 Paul Howarth <paul@city-fan.org> - 0.46-1
- Update to 0.46
  - Avoid variable shadowing to improve debuggability
- Update patches as needed

* Sat Aug  6 2016 Paul Howarth <paul@city-fan.org> - 0.44-1
- Update to 0.44
  - Note that dropping privileges during a capture can lead to temporary files
    not being cleaned up

* Wed Jun  1 2016 Paul Howarth <paul@city-fan.org> - 0.42-1
- Update to 0.42
  - Fixed some failing tests when STDIN is routed to /dev/null

* Mon May 23 2016 Paul Howarth <paul@city-fan.org> - 0.40-1
- Update to 0.40
  - Skip some tests if locale can't be determined
- BR: perl-generators where available
- Simplify find command using -delete
- Update patch for building with Test::More < 0.88

* Mon Feb 29 2016 Paul Howarth <paul@city-fan.org> - 0.36-1
- Update to 0.36
  - Fix typos in documentation

* Fri Feb 19 2016 Paul Howarth <paul@city-fan.org> - 0.34-1
- Update to 0.34
  - Application of layers to handles during and after capture now attempts to
    more accurately duplicate the original layers, including potential
    duplicate layers; because of the unusual ways that layers are ordered and
    applied, exact duplication is not guaranteed, but this should be better
    than what Capture::Tiny did before
  - Avoids a hard crash on Windows with Perl < 5.20 if a fork occurs in a
    capture block; also documented the risks and lack of support for forks in
    capture blocks
  - Changed internal formatting of documentation
- Update patch for building with Test::More < 0.88

* Tue Jun 23 2015 Paul Howarth <paul@city-fan.org> - 0.30-3
- Perl 5.22 rebuild

* Mon May 18 2015 Paul Howarth <paul@city-fan.org> - 0.30-1
- Update to 0.30
  - Fix double filehandle close error with tee on Windows (which started
    warning during the perl 5.21.x series, causing tests to fail)

* Wed Feb 11 2015 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28
  - Remove test that optionally used Inline::C to avoid spurious test failures;
    also, Inline::C had become a fairly heavy (if optional) dependency
  - Clarify in docs that PERL_CAPTURE_TINY_TIMEOUT is an internal control, not
    a timeout of the code reference being captured
- Update patch for building with Test::More < 0.88

* Wed Nov  5 2014 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - Actually check for Inline::C in tests, not just Inline
- Update patch for building with Test::More < 0.88

* Thu Sep  4 2014 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - Amended recommended modules to list Inline::C rather than Inline
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Fri Feb  7 2014 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Closed security hole in use of semaphore flag in /tmp; now opens the
    semaphore using O_CREAT|O_EXCL (CVE-2014-1875)

* Mon Oct 21 2013 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23
  - Minimum Perl prereq is back to 5.6
  - Added warning about using @_ in a capture block
- Package new CONTRIBUTING file
- Drop redundant patch for building with old versions of ExtUtils::MakeMaker

* Tue Jul 16 2013 Paul Howarth <paul@city-fan.org> - 0.22-2
- Don't run the extra tests when bootstrapping

* Thu Mar 28 2013 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
  - Issue tracker is now github
- BR: perl(File::Spec::Functions) and perl(List::Util) for new report versions
  test
- BR: perl(Test::MinimumVersion) for new release test
- Update patch for building with ExtUtils::MakeMaker < 6.30

* Thu Nov 15 2012 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - Skips tee and leak tests for closed STDIN on Perl prior to 5.12 when
    PERL_UNICODE=D; documented lack of support as a known issue
  - Isolated tee subprocesses from effects of PERL_UNICODE as a precaution
    (though this did not fix the above issue)
  - Improved layer detection for handles proxied due to being closed or tied

* Wed Sep 19 2012 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - Nested merged captures that include an external program call no longer leak
    STDERR to the outer scope (CPAN RT#79376)
- Drop upstreamed spelling patch

* Tue Aug  7 2012 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19
  - Work around Perl RT#114404 by forcing PerlIO layers back on original
    handles (CPAN RT#78819)
- Drop BR: perl(Test::Requires) and associated patch for older distributions,
  no longer required

* Thu Jul 19 2012 Paul Howarth <paul@city-fan.org> - 0.18-3
- Import from Fedora

* Sat Jun 16 2012 Petr Pisar <ppisar@redhat.com> - 0.18-2
- Perl 5.16 rebuild

* Mon May 07 2012 Petr Šabata <contyk@redhat.com> - 0.18-1
- 0.18 bump

* Thu Feb 23 2012 Petr Šabata <contyk@redhat.com> - 0.17-1
- 0.17 bump

* Mon Feb 13 2012 Petr Šabata <contyk@redhat.com> - 0.16-1
- 0.16 bump

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jan 02 2012 Petr Šabata <contyk@redhat.com> - 0.15-1
- 0.15 bump

* Mon Dec 05 2011 Petr Šabata <contyk@redhat.com> - 0.13-1
- 0.13 bump

* Fri Dec 02 2011 Petr Pisar <ppisar@redhat.com> - 0.12-1
- 0.12 bump

* Wed Jun 15 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.11-2
- Perl mass rebuild

* Fri May 20 2011 Petr Sabata <psabata@redhat.com> - 0.11-1
- 0.11 bump
- Removing defattr

* Wed Feb 09 2011 Petr Pisar <ppisar@redhat.com> - 0.10-1
- 0.10 bump

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.09-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jan 28 2011 Petr Pisar <ppisar@redhat.com> - 0.09-1
- 0.09 bump
- Remove BuildRoot stuff
- Migrate from Module::Build to ExtUtils::MakeMaker
- Install into perl core directory

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.08-2
- Rebuild to fixing problems with vendorarch/lib (#661697)

* Mon Jun 21 2010 Petr Pisar <ppisar@redhat.com> - 0.08-1
- 0.08 bump (bug #606277)

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.07-2
- Mass rebuild with perl-5.12.0

* Wed Jan 27 2010 Marcela Mašláňová <mmaslano@redhat.com> - 0.07-1
- Update

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.06-2
- Rebuild against perl 5.10.1

* Tue Aug 11 2009 Marcela Mašláňová <mmaslano@redhat.com> - 0.06-1
- Update

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Apr 27 2009 Marcela Mašláňová <mmaslano@redhat.com> - 0.05-1
- Specfile autogenerated by cpanspec 1.78
